bonsoir library
Bonsoir, created by Skyost Github : https://github.com/Skyost/Bonsoir
Classes
-
BonsoirAction<
T extends BonsoirEvent> - This class serves as the stream source for the implementations to override.
-
BonsoirActionHandler<
T extends BonsoirEvent> - Allows to handle a Bonsoir action.
- BonsoirBroadcast
- Allows to broadcast a service on the network.
- BonsoirBroadcastEvent
- A Bonsoir broadcast event.
- BonsoirBroadcastNameAlreadyExistsEvent
- Triggered when a name conflicts occurs.
- BonsoirBroadcastStartedEvent
- Triggered when the broadcast has started.
- BonsoirBroadcastStoppedEvent
- Triggered when the broadcast has stopped.
- BonsoirBroadcastUnknownEvent
- Unknown event occurred.
- BonsoirDiscovery
- Allows to run a network discovery.
- BonsoirDiscoveryEvent
- A Bonsoir discovery event.
- BonsoirDiscoveryServiceFoundEvent
- Triggered when a service has been found.
- BonsoirDiscoveryServiceLostEvent
- Triggered when a service has been lost.
- BonsoirDiscoveryServiceResolvedEvent
- Triggered when a service has been found and resolved.
- BonsoirDiscoveryServiceResolveFailedEvent
- Triggered when a service has been found but cannot be resolved.
- BonsoirDiscoveryServiceUpdatedEvent
- Triggered when a service has been updated.
- BonsoirDiscoveryStartedEvent
- Triggered when the discovery has started.
- BonsoirDiscoveryStoppedEvent
- Triggered when the discovery has stopped.
- BonsoirDiscoveryUnknownEvent
- Unknown event occurred.
- BonsoirEvent
- Represents a Bonsoir event.
- BonsoirPlatformInterface
- A Bonsoir class that allows to either broadcast a service or to discover services on the network.
- BonsoirPlatformInterfaceLogMessages
- Contains a set of messages that can be logged by the native platform interface. This ensure a consistency across platforms.
- BonsoirService
- Represents a broadcastable network service.
- BonsoirServiceNormalizer
- Contains various methods that helps conforming to RFC 6335 and RFC 6763.
- MethodChannelBonsoir
- A Bonsoir class that allows to either broadcast a service or to discover services on the network using a method channel.
-
MethodChannelBonsoirAction<
T extends BonsoirEvent> - Abstract class that contains all methods that are communicating with the native side of the plugin.
- MethodChannelBonsoirBroadcastAction
-
Implementation of
MethodChannelBonsoirEventsfor the broadcast action. - MethodChannelBonsoirDiscoveryAction
-
Implementation of
MethodChannelBonsoirEventsfor the discovery action.
Mixins
- ServiceResolver
- An action that is capable of resolving a service.
Extensions
- Resolve on BonsoirService
- Allows to resolve a service.
Constants
- kDnsSdMetaQuery → const String
- The DNS-SD meta query.